pub struct WatchConfig {
pub debounce_ms: u64,
pub min_interval_ms: u64,
pub sync_on_start: bool,
pub dry_run: bool,
pub enable_tray: bool,
pub tray_icon: Option<String>,
pub periodic_sync_interval_ms: Option<u64>,
}Expand description
Watch mode configuration
Fields
debounce_ms: u64How long to wait after changes before syncing (milliseconds)
min_interval_ms: u64Minimum interval between syncs (milliseconds)
sync_on_start: boolWhether to sync on startup
dry_run: boolDry run mode - detect changes but don’t sync
enable_tray: boolEnable system tray indicator (requires tray feature)
tray_icon: Option<String>Custom tray icon: a freedesktop icon name or a path to an image file
periodic_sync_interval_ms: Option<u64>Optional periodic sync interval in milliseconds. When set, sync attempts are triggered even without filesystem events.